# daemonflux: DAta-drivEn and MuOn-calibrated Neutrino flux

Daemonflux is a tabulated/splined version of the an atmospheric flux model calibrated on muon spectrometer data.

## Requirements
 * `Python > 3.7`, `numpy`, `scipy`
 * `matplotlib` for examples

## Installation

`pip install daemonflux`

The code currently requires the spline files in binary format from us. The files will be made available once the work is submitted to the journal.

## Usage

Follow the [example](examples/example.ipynb).

## Citation

Coming soon.

## LICENSE

[BSD 3-Clause License](LICENSE)
